#!/usr/bin/perl -cw
# 
# You should check the syntax of this file before using it in an auto-install.
# You can do this with 'perl -cw auto_inst.cfg.pl' or by executing this file
# (note the '#!/usr/bin/perl -cw' on the first line).

my $mandriva_theme =
  $ENV{DRAKLIVE_PRODUCT} =~ /flash/i ?
    'Powerpack' :
    'One';
my $mandriva_config =
  $ENV{DRAKLIVE_PRODUCT} =~ /flash/i ?
    'flash' :
    'one';
my @desktops = split(/\|/, $ENV{DRAKLIVE_DESKTOP});
my $has_kde = any { /^KDE/ } @desktops;
my $has_kde3 = member('KDE', @desktops);
my $has_kde4 = member('KDE4', @desktops);
my $has_gnome = member('GNOME', @desktops);
my $has_xfce = member('xfce4', @desktops);

$o = {
       'media' => [
           {
               type => 'media_cfg',
               url => 'drakx://media',
               selected_names => join(',',
                                      'Main', 'Main Updates',
                                      'Contrib', 'Contrib Updates',
                                      'Non-free', 'Non-free Updates',
                                      'Restricted', 'Restricted Updates',
                                      if_($has_xfce, 'Main Backports', 'Contrib Backports'),
                                  ),
           },
           if_($ENV{DRAKLIVE_ARCH} eq 'x86_64' && $ENV{DRAKLIVE_ADDITIONAL_REPOSITORY},
               { type => 'media', url => $ENV{DRAKLIVE_ADDITIONAL_REPOSITORY} . '/i586/media/main/release' },
               { type => 'media', url => $ENV{DRAKLIVE_ADDITIONAL_REPOSITORY} . '/i586/media/main/updates' },
           ),
       ],
       'rpmsrate_flags_chosen' => {
           LIVE => 1,
           (map { ("CAT_$_" => 1) } (
               # office
               qw(OFFICE SPELLCHECK PIM ARCHIVING PRINTER),
               # multimedia
               qw(AUDIO VIDEO GRAPHICS),
               # internet
               qw(NETWORKING_WWW NETWORKING_MAIL NETWORKING_NEWS COMMUNICATIONS NETWORKING_CHAT),
               qw(NETWORKING_FILE_TRANSFER NETWORKING_IRC NETWORKING_INSTANT_MESSAGING NETWORKING_DNS),
               # network
               qw(NETWORKING_REMOTE_ACCESS NETWORKING_FILE),
               qw(NETWORKING_REMOTE_ACCESS_SERVER),
               # config
               qw(CONFIG),
               # console
               qw(EDITORS TERMINALS TEXT_TOOLS SHELLS FILE_TOOLS),
               # system
               qw(SYSTEM MINIMAL_DOCS X ACCESSIBILITY THEMES),
               if_($has_kde3, qw(KDE3)),
               if_($has_kde4, qw(KDE)),
               if_($has_gnome, qw(GNOME)),
               if_($has_xfce, qw(XFCE)),
               if_($ENV{DRAKLIVE_PRODUCT} =~ /gaming/i, qw(GAMES)),
           )),
       },
       # so that rpmsrate flags are really used
       'compssListLevel' => 5, # default from install_steps_interactive
       'skipped_packages' => [
           #- do not allow source dkms to be installed
           'dkms',
	   'gstreamer0.10-plugins-ugly', #- 'ugly' plugins will be installed through codeina
           if_($ENV{DRAKLIVE_PRODUCT} !~ /guadec/i, 'gcc'),
           "/^mandriva-theme(?!-common|-$mandriva_theme(?:|-screensaver)-)/",
           "/^mandriva-release(?!-common|-$mandriva_theme)-/",
           if_($ENV{DRAKLIVE_ARCH} eq 'x86_64',
               #- !TYPE"64bit" packages are selected by default for live
               #- skip i586 ones if not relevant
               'libqca1-tls',
           ),
           if_($ENV{DRAKLIVE_PRODUCT} !~ /gaming/i, #- non-DVD products
               #- from task-kde Suggests
               #- skipping them prevents task-kde from being installed,
               #- but its dependencies seems to be pulled correctly
               'kdeaddons',
               'kdenlive',
               'kdepim-kpilot',
               'konversation',
               'kerry',
               'kde-i18n-en_GB', 'openoffice.org-l10n-en_GB', 'mozilla-firefox-en_GB',
               if_($ENV{DRAKLIVE_LANGS} !~ /\bpt\b/ && $ENV{DRAKLIVE_REGION} ne 'all',
                   #- do not install pt translations if only pt_BR is explicitely selected
                   'kde-i18n-pt', 'kde4-l10n-pt',
                   'mozilla-firefox-pt',
               ),
               if_($ENV{DRAKLIVE_PRODUCT} !~ /flash/i, 'task-printing-scanning'),
               'qtradio', 'kradio',
               if_(!$has_gnome, 'gnome-media'),
               if_(!$has_gnome, 'system-config-printer'),
               'poppler-data', 'tetex',
               'fglrx-control-center',
               '/^gimp-help/',
               '/^openoffice.org-help/',
               if_(!$has_gnome, 'yelp'),
               '/^nvidia.*-doc-html/',
               if_(member($ENV{DRAKLIVE_REGION}, qw(asia extra-i18n)),
                   if_($has_kde3, 'kdeaccessibility'),
               ),
               if_($has_kde4, 'k3b'),
               ($ENV{DRAKLIVE_PRODUCT} =~ /flash/i
                ? ('/openjdk/', 'java-1.5.0-gcj')
                : '/java/'),
               'asihpi-firmware', 'hdsploader', 'mixartloader', 'pcxhrloader', 'usx2yloader', 'vxloader',
               'drakfax', 'efax',
           ),
           if_($ENV{DRAKLIVE_PRODUCT} !~ /gaming/i,
               #- from task-kde Suggests
               'kdegames', 'kdegames4',
               'kdetoys',
           ),
           if_(!$ENV{DRAKLIVE_COMMERCIAL},
               'skype',
           ),

           #- bluez-pin provide
           if_(!$has_kde3, 'kdebluetooth'),
           if_(!$has_kde4, 'kdebluetooth4'),

           if_($has_kde4, 'quassel'),

           if_(!$has_kde3, 'compiz-decorator-kde'), #- provides compiz-decorator
           if_(!$has_kde4, 'compiz-decorator-kde4'), #- provides compiz-decorator
           if_(!$has_kde3, 'openoffice.org-kde'),
           if_(!$has_kde3, 'pinentry-qt'), #- qt3 app
           'kdebase-kate', 'kdeaddons-kate', #- development tool
           '/noatun/', #- prefer amarok
           #- FIXME: this broken package should be removed from non-free
           'a320raid',

           if_($ENV{DRAKLIVE_PRODUCT} =~ /guadec/i, 'rfbdrake'),

           if_($has_kde4, 'digikam'), #- linked with marble, too big
           if_(!$has_kde3, 'eva'), #- qt3 app, to be removed/downgraded in rpmsrate?
           if_($has_kde4, 'gdb'), #- suggested by one of the kde4 base package
           if_($has_kde4, 'mozilla-thunderbird'), #- we have kmail
           if_($has_kde4, 'ufraw-gimp'), #- too big :(
           if_($has_kde4, 'task-3ddesktop-kde'),

           if_($has_gnome, 'mozilla-thunderbird'), #- we have evolution 
           if_($has_gnome, 'beagle'),
           '/^kernel-server-/', if_($ENV{DRAKLIVE_ARCH} ne 'x86_64', '/^kernel-deskop-/'),
       ],
       'default_packages' => [
           if_($has_kde3, "$mandriva_config-kde-config"),
           if_($has_kde4, "$mandriva_config-kde4-config"),

           #- broken updates
           if_($has_kde4, 'kde4-splash-mdv'),

           #- live resize/install/copy tools
           if_($ENV{DRAKLIVE_MEDIA} eq 'usb', 'draklive-resize'),

           if_($ENV{DRAKLIVE_PRODUCT} =~ /gaming/i, 'task-games'),

           #- inline task-3ddesktop-kde for KDE3
           if_($has_kde3, 'x11-server-xgl', 'compiz-fusion', 'metisse', 'compiz-decorator-kde4', 'compiz-decorator-gtk'),

           #- should be in x11-driver-video (#42909)
           'x11-driver-video-via',

           #- should be level 5 in rpmsrate
           if_($has_gnome, 'vino', 'vinagre'),

           if_($ENV{DRAKLIVE_PRODUCT} =~ /flash/i,
               'samba-client',
               'RealPlayer', 'RealPlayer-rpnp',
               'FlashPlayer',
               'java-1.6.0-sun',
               'mozilla-firefox-ext-google-toolbar',
               'filezilla', #- FIXME: bump to level 5 in rpmsrate?
               if_($has_kde3, 'klamav'),
               'nut-server',
               'mozilla-thunderbird',
               if_($ENV{DRAKLIVE_REGION} eq 'all', map { "mozilla-thunderbird-$_" } qw(ca cs de el es es_AR eu fi fr gu_IN he hu it ja ko nb nl pa_IN pl pt_BR ru sk sl sv tr zh_CN)),
               if_($ENV{DRAKLIVE_PRODUCT} =~ /guadec/i,
                   'fonts-ttf-gurmukhi',
                   'cheese',
                   'anjuta',
               ),
           ),
       ],
       'meta_class' => 'desktop',
       'desktop' => first(@desktops),
       if_($ENV{DRAKLIVE_DEFAULT_USER}, 'autologin' => $ENV{DRAKLIVE_DEFAULT_USER}),
       # explicitely specify the security level, so that environment of the build machine doesn't take precedence
       'security' => 1,
       'useSupermount' => 'magicdev',
       'users' => [
		    if_($ENV{DRAKLIVE_DEFAULT_USER}, {
		      'icon' => 'default',
		      'realname' => '',
		      'uid' => '',
		      'groups' => [],
		      'name' => $ENV{DRAKLIVE_DEFAULT_USER},
		      'shell' => '/bin/bash',
		      'gid' => ''
		    }),
		  ],
       'locale' => {
                     'country' => 'US',
                     'IM' => undef,
                     'lang' => 'en_US',
                     'langs' => +{
                         $ENV{DRAKLIVE_REGION} eq 'all' ? (all => 1) : (map { $_ => 1 } split(':', $ENV{DRAKLIVE_LANGS}))
                      },
                     'utf8' => 1
                   },
       'authentication' => {
			     'shadow' => 1,
			     'local' => 1,
			     'md5' => 1
			   },
       'superuser' => {
			'pw' => '',
			'realname' => 'root',
			'uid' => '0',
			'shell' => '/bin/bash',
			'home' => '/root',
			'gid' => '0'
		      },
       'keyboard' => {
		       'GRP_TOGGLE' => '',
		       'KBCHARSET' => 'C',
		       'KEYBOARD' => 'us',
		       'KEYTABLE' => 'us'
		     },
       'timezone' => {
		       'ntp' => undef,
		       'timezone' => 'America/New_York',
		       'UTC' => 1
		     },
       'X' => { disabled => 1 }, #- disable auto-configuration that may install unwanted packages
       'match_all_hardware' => 1,
       'excludedocs' => 0,
       'postInstall' => join(";",
                             "perl -pi -e 's/^id:3:initdefault:/id:5:initdefault:/' '/etc/inittab'",
                             if_($has_xfce, "rm -f /etc/sysconfig/autologin"),
                             if_($mandriva_theme eq 'Flash',
                                 #- set blue gtk theme for Flash in Gnome
                                 "/usr/bin/gconftool-2 --config-source=xml::/etc/gconf/gconf.xml.local-defaults/ --direct --type=string --set /apps/metacity/general/theme 'Ia Ora Blue'",
                                 "/usr/bin/gconftool-2 --config-source=xml::/etc/gconf/gconf.xml.local-defaults/ --direct --type=string --set /desktop/gnome/interface/gtk_theme 'Ia Ora Blue'",
                                 #- set blue gtk theme for Flash in GTK
                                 "perl -pi -e 's/META_CLASS=.*/META_CLASS=powerpack/' /etc/sysconfig/system",
                                 "echo MDV_MENU_STYLE=discovery > /etc/sysconfig/menustyle",
                                 if_(!$ENV{DRAKLIVE_COMMERCIAL},
                                     "mkdir -p /usr/share/mdk/desktop/flash",
                                     "cp -a /usr/share/mdk/desktop/one/subscribe.desktop /usr/share/mdk/desktop/flash",
                                 ),
                             ),
                         ),
       'autoExitInstall' => 1,
       'keep_unrequested_dependencies' => 0,
     };

my $old = \&install::pkgs::empty_packages;
undef *install::pkgs::empty_packages;
*install::pkgs::empty_packages = sub {
    my $packages = &$old;
    $packages->{debug_URPM} = sub { log::l("XXX: $_[0]") };
    $packages;
};
